import orjson
import websockets
import os
import asyncio
from collections import defaultdict

WEBSOCKET_URL = os.getenv("WEBSOCKET_URL", "ws://archivebot.archivingyoursh.it/stream")


Buffer = defaultdict(list)


async def main():
    async with websockets.connect(WEBSOCKET_URL) as websocket:
        while True:
            message = await websocket.recv()
            try:
                data = orjson.loads(message)
            except:
                print("?")
                continue
            Buffer[data["job_data"]["ident"]].append(message)


# every second, we flush to disk
async def clean_buffer():
    while True:
        for job, data in Buffer.items():
            with open(f"{job}.jsonl", "a") as f:
                f.write("\n".join(data) + "\n")
        Buffer.clear()
        await asyncio.sleep(1)


async def start():
    await asyncio.gather(main(), clean_buffer())


if __name__ == "__main__":
    asyncio.run(start())

